Reanalyse powerNLSEM object
reanalyse.powerNLSEM(
out,
test = NULL,
powerLevels = NULL,
power_modeling_method = NULL,
alpha = NULL,
alpha_power_modeling = NULL
)Returns list of desired sample sizes per effect for each powerLevel. Nall refers to the sample size required per power level for all coefficients. Npower is a matrix containing the desired sample sizes per effect for every power level.
object of class powerNLSEM
Should the parameter be tested with a directed hypothesis (onesided) or with an undirected hypothesis (twosided, also equivalent to Wald-Test for single parameter). Default to NULL, then the same as in fitted powerNLSEM object is used.
Power levels for which the desired sample sizes should be computed. Needs to be a vector. Default to NULL indicating to use same power rate used in powerNLSEM object.
Character indicating the power modeling method used. Default to NULL, indicating to use the same power modeling method as was used in the powerNLSEM object.
Type I-error rate for significance decision. Default to .05.
Type I-error rate for confidence band around predicted power rate. Used to ensure that the computed N keeps the desired power value (with the given Type I-error rate alpha_power_modeling divided by 2). If set to 1, no confidence band is used. Default to .05.